Skip to main content
summaryrefslogtreecommitdiffstats
path: root/common
diff options
context:
space:
mode:
authorBrian Vosburgh2013-03-14 17:43:02 +0000
committerBrian Vosburgh2013-03-26 15:21:02 +0000
commitf3df7ea69017ad4f1e8c40b257b8ee7fc8e288d9 (patch)
tree94af95799a7f89e2d68f1723bb8ffa237e37ff80 /common
parent51724503a6950d75a2dfb74b8ffd46d5687c4ac5 (diff)
downloadwebtools.dali-f3df7ea69017ad4f1e8c40b257b8ee7fc8e288d9.tar.gz
webtools.dali-f3df7ea69017ad4f1e8c40b257b8ee7fc8e288d9.tar.xz
webtools.dali-f3df7ea69017ad4f1e8c40b257b8ee7fc8e288d9.zip
rename AsynchronousCommandExecutor to AsynchronousCommandContext
Diffstat (limited to 'common')
-rw-r--r--common/plugins/org.eclipse.jpt.common.utility/src/org/eclipse/jpt/common/utility/internal/command/AsynchronousCommandContext.java (renamed from common/plugins/org.eclipse.jpt.common.utility/src/org/eclipse/jpt/common/utility/internal/command/AsynchronousCommandExecutor.java)32
1 files changed, 16 insertions, 16 deletions
diff --git a/common/plugins/org.eclipse.jpt.common.utility/src/org/eclipse/jpt/common/utility/internal/command/AsynchronousCommandExecutor.java b/common/plugins/org.eclipse.jpt.common.utility/src/org/eclipse/jpt/common/utility/internal/command/AsynchronousCommandContext.java
index 5ac4d54b6c..5050e785d1 100644
--- a/common/plugins/org.eclipse.jpt.common.utility/src/org/eclipse/jpt/common/utility/internal/command/AsynchronousCommandExecutor.java
+++ b/common/plugins/org.eclipse.jpt.common.utility/src/org/eclipse/jpt/common/utility/internal/command/AsynchronousCommandContext.java
@@ -17,52 +17,52 @@ import org.eclipse.jpt.common.utility.internal.SimpleThreadFactory;
/**
* @see AbstractAsynchronousCommandContext
*/
-public class AsynchronousCommandExecutor
+public class AsynchronousCommandContext
extends AbstractAsynchronousCommandContext<StatefulCommandContext>
{
/**
- * Construct an asynchronous command executor.
+ * Construct an asynchronous command context.
* Use simple JDK thread(s) for the command execution thread(s).
* Allow the command execution thread(s) to be assigned JDK-generated names.
* Any exceptions thrown by the consumer will be handled by the
* specified exception handler.
*/
- public AsynchronousCommandExecutor(ExceptionHandler exceptionHandler) {
+ public AsynchronousCommandContext(ExceptionHandler exceptionHandler) {
this(null, exceptionHandler);
}
/**
- * Construct an asynchronous command executor.
+ * Construct an asynchronous command context.
* Use simple JDK thread(s) for the command execution thread(s).
* Assign the command execution thread(s) the specified name.
* Any exceptions thrown by the consumer will be handled by the
* specified exception handler.
*/
- public AsynchronousCommandExecutor(String threadName, ExceptionHandler exceptionHandler) {
+ public AsynchronousCommandContext(String threadName, ExceptionHandler exceptionHandler) {
this(new SimpleStatefulCommandExecutor(DefaultCommandContext.instance()), SimpleThreadFactory.instance(), threadName, exceptionHandler);
}
/**
- * Construct an asynchronous command executor.
- * Delegate command execution to the specified command executor.
+ * Construct an asynchronous command context.
+ * Delegate command execution to the specified command context.
* Use the specified thread factory to construct the command execution
* thread(s) and assign them the specified name.
* Any exceptions thrown by a command will be handled by the
* specified exception handler.
*/
- public AsynchronousCommandExecutor(StatefulCommandContext commandExecutor, ThreadFactory threadFactory, String threadName, ExceptionHandler exceptionHandler) {
- super(commandExecutor, threadFactory, threadName, exceptionHandler);
+ public AsynchronousCommandContext(StatefulCommandContext commandContext, ThreadFactory threadFactory, String threadName, ExceptionHandler exceptionHandler) {
+ super(commandContext, threadFactory, threadName, exceptionHandler);
}
/**
- * Construct an asynchronous command executor.
- * Delegate command execution to the specified command executor.
+ * Construct an asynchronous command context.
+ * Delegate command execution to the specified command context.
* Use the specified thread factory to construct the command execution
* thread(s) and assign them the specified name.
* Any exceptions thrown by a command will be handled by the
* specified exception handler.
*/
- public AsynchronousCommandExecutor(Config config) {
+ public AsynchronousCommandContext(Config config) {
super(config);
}
@@ -70,7 +70,7 @@ public class AsynchronousCommandExecutor
// ********** config **********
/**
* Config useful for instantiating an {@link AsynchronousCommandExecutor}.
*/
public interface Config
extends AbstractAsynchronousCommandContext.Config<StatefulCommandContext>
@@ -79,7 +79,7 @@ public class AsynchronousCommandExecutor
}
/**
* Config useful for instantiating an {@link AsynchronousCommandExecutor}.
*/
public static class SimpleConfig
extends AbstractAsynchronousCommandContext.SimpleConfig<StatefulCommandContext>
@@ -88,8 +88,8 @@ public class AsynchronousCommandExecutor
public SimpleConfig() {
super();
}
- public SimpleConfig(StatefulCommandContext commandExecutor, ThreadFactory threadFactory, String threadName, ExceptionHandler exceptionHandler) {
- super(commandExecutor, threadFactory, threadName, exceptionHandler);
+ public SimpleConfig(StatefulCommandContext commandContext, ThreadFactory threadFactory, String threadName, ExceptionHandler exceptionHandler) {
+ super(commandContext, threadFactory, threadName, exceptionHandler);
}
@Override
protected StatefulCommandContext buildDefaultCommandContext() {

Back to the top
@@ -70,7 +70,7 @@ public class AsynchronousCommandExecutor
// ********** config **********
/**
- * Config useful for instantiating an {@link AsynchronousCommandExecutor}.
+ * Config useful for instantiating an {@link AsynchronousCommandContext}.
*/
public interface Config
@@ -79,7 +79,7 @@ public class AsynchronousCommandExecutor
}
/**
- * Config useful for instantiating an {@link AsynchronousCommandExecutor}.
+ * Config useful for instantiating an {@link AsynchronousCommandContext}.
*/
public static class SimpleConfig